==> haskell-network-run-0.3.0-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-run.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-run
version:              0.3.0
visibility:           public
id:                   network-run-0.3.0-3dkZW8w9kmjIujRf9jjWnT
key:                  network-run-0.3.0-3dkZW8w9kmjIujRf9jjWnT
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Simple network runner library
description:          Simple functions to run network clients and servers.
category:             Network
abi:                  c5f51a4e50975d02e2dc9b7cb1452a83
exposed:              True
exposed-modules:
    Network.Run.TCP Network.Run.TCP.Timeout Network.Run.UDP

hidden-modules:       Network.Run.Core
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-run-0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-run-0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-run-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-run
hs-libraries:         HSnetwork-run-0.3.0-3dkZW8w9kmjIujRf9jjWnT
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-LColH4Hos0S6e9tGqh8fY1
    time-manager-0.0.1-JjJ6S5ghvsY1Ys2qNLDVHs

haddock-interfaces:   /usr/share/doc/haskell-network-run/html/network-run.haddock
haddock-html:         /usr/share/doc/haskell-network-run/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-run-0.3.0-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-run.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-run
version:              0.3.0
visibility:           public
id:                   network-run-0.3.0-C9ul89t19hb8Qk8dtoGio7
key:                  network-run-0.3.0-C9ul89t19hb8Qk8dtoGio7
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Simple network runner library
description:          Simple functions to run network clients and servers.
category:             Network
abi:                  d684f09b0fe27c6b869a269c662186bd
exposed:              True
exposed-modules:
    Network.Run.TCP Network.Run.TCP.Timeout Network.Run.UDP

hidden-modules:       Network.Run.Core
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-run-0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-run-0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-run-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-run
hs-libraries:         HSnetwork-run-0.3.0-C9ul89t19hb8Qk8dtoGio7
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-82nHJL6Luo48oDimrIyJyV
    time-manager-0.0.1-4aZNzut2LhTCjngq7qqp3p

haddock-interfaces:   /usr/share/doc/haskell-network-run/html/network-run.haddock
haddock-html:         /usr/share/doc/haskell-network-run/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
